@@ -7,20 +7,22 @@ use std::{
     rc::Rc,
 };
 
-pub(crate) const ARGS: &[Arg] = &[
-    Arg::new("--all", "Stage all modified and deleted files", false),
-    Arg::new("--allow-empty", "Allow empty commit", false),
-    Arg::new("--verbose", "Show diff of changes to be committed", false),
-    Arg::new("--no-verify", "Disable hooks", false),
-    Arg::new(
-        "--reset-author",
-        "Claim authorship and reset author date",
-        false,
-    ),
-    // TODO -A Override the author (--author=)
-    Arg::new("--signoff", "Add Signed-off-by line", false),
-    // TODO -C Reuse commit message (--reuse-message=)
-];
+pub(crate) fn init_args() -> Vec<Arg> {
+    vec![
+        Arg::new_flag("--all", "Stage all modified and deleted files", false),
+        Arg::new_flag("--allow-empty", "Allow empty commit", false),
+        Arg::new_flag("--verbose", "Show diff of changes to be committed", false),
+        Arg::new_flag("--no-verify", "Disable hooks", false),
+        Arg::new_flag(
+            "--reset-author",
+            "Claim authorship and reset author date",
+            false,
+        ),
+        // TODO -A Override the author (--author=)
+        Arg::new_flag("--signoff", "Add Signed-off-by line", false),
+        // TODO -C Reuse commit message (--reuse-message=)
+    ]
+}
 
 #[derive(Display)]
 #[display(fmt = "Commit")]
@@ -32,6 +34,7 @@ impl OpTrait for Commit {
             cmd.args(["commit"]);
             cmd.args(state.pending_menu.as_ref().unwrap().args());
 
+            state.close_menu();
             state.run_cmd_interactive(term, cmd)?;
             Ok(())
         }))
@@ -48,6 +51,7 @@ impl OpTrait for CommitAmend {
             cmd.args(["commit", "--amend"]);
             cmd.args(state.pending_menu.as_ref().unwrap().args());
 
+            state.close_menu();
             state.run_cmd_interactive(term, cmd)?;
             Ok(())
         }))
@@ -65,6 +69,8 @@ impl OpTrait for CommitFixup {
 
                 Some(Rc::new(move |state: &mut State, term: &mut Term| {
                     let args = state.pending_menu.as_ref().unwrap().args();
+
+                    state.close_menu();
                     state.run_cmd_interactive(term, commit_fixup_cmd(&args, &rev))
                 }))
             }
