@@ -1,7 +1,7 @@
-use super::{cmd, cmd_arg, OpTrait};
+use super::OpTrait;
 use crate::{git::diff::PatchMode, items::TargetData, state::State, term::Term, Action};
 use derive_more::Display;
-use std::{ffi::OsStr, process::Command, rc::Rc};
+use std::{ffi::OsString, process::Command, rc::Rc};
 
 #[derive(Display)]
 #[display(fmt = "Unstage")]
@@ -10,12 +10,11 @@ impl OpTrait for Unstage {
     fn get_action(&self, target: Option<&TargetData>) -> Option<Action> {
         let action = match target.cloned() {
             Some(TargetData::AllStaged) => unstage_staged(),
-            Some(TargetData::Delta(d)) => cmd_arg(unstage_file_cmd, d.new_file.into()),
-            Some(TargetData::Hunk(h)) => cmd(h.format_patch().into_bytes(), unstage_patch_cmd),
-            Some(TargetData::HunkLine(h, i)) => cmd(
+            Some(TargetData::Delta(d)) => unstage_file(d.new_file.into()),
+            Some(TargetData::Hunk(h)) => unstage_patch(h.format_patch().into_bytes()),
+            Some(TargetData::HunkLine(h, i)) => unstage_line(
                 h.format_line_patch(i..(i + 1), PatchMode::Reverse)
                     .into_bytes(),
-                unstage_line_cmd,
             ),
             _ => return None,
         };
@@ -31,25 +30,39 @@ fn unstage_staged() -> Action {
     Rc::new(move |state: &mut State, term: &mut Term| {
         let mut cmd = Command::new("git");
         cmd.args(["reset", "HEAD", "--"]);
+
+        state.close_menu();
         state.run_cmd(term, &[], cmd)
     })
 }
 
-fn unstage_file_cmd(file: &OsStr) -> Command {
-    let mut cmd = Command::new("git");
-    cmd.args(["restore", "--staged"]);
-    cmd.arg(file);
-    cmd
+fn unstage_file(file: OsString) -> Action {
+    Rc::new(move |state: &mut State, term: &mut Term| {
+        let mut cmd = Command::new("git");
+        cmd.args(["restore", "--staged"]);
+        cmd.arg(&file);
+
+        state.close_menu();
+        state.run_cmd(term, &[], cmd)
+    })
 }
 
-fn unstage_patch_cmd() -> Command {
-    let mut cmd = Command::new("git");
-    cmd.args(["apply", "--cached", "--reverse"]);
-    cmd
+fn unstage_patch(input: Vec<u8>) -> Action {
+    Rc::new(move |state: &mut State, term: &mut Term| {
+        let mut cmd = Command::new("git");
+        cmd.args(["apply", "--cached", "--reverse"]);
+
+        state.close_menu();
+        state.run_cmd(term, &input, cmd)
+    })
 }
 
-fn unstage_line_cmd() -> Command {
-    let mut cmd = Command::new("git");
-    cmd.args(["apply", "--cached", "--reverse", "--recount"]);
-    cmd
+fn unstage_line(input: Vec<u8>) -> Action {
+    Rc::new(move |state: &mut State, term: &mut Term| {
+        let mut cmd = Command::new("git");
+        cmd.args(["apply", "--cached", "--reverse", "--recount"]);
+
+        state.close_menu();
+        state.run_cmd(term, &input, cmd)
+    })
 }
